import React from 'react'
import annotator from 'annotator'
import styled, { createGlobalStyle } from 'styled-components'
import { th, lighten } from '@pubsweet/ui-toolkit'

const Annotate = styled.div`
  .annotator-hl {
    background-color: ${lighten('colorWarning', 20)};
    &:hover {
      background-color: ${th('colorWarning')};
    }
  }
`
const AnnotatorStyles = createGlobalStyle`
  .annotator-widget {
    box-shadow: 0 0 8px #ccc !important;
    border-radius: ${th('borderRadius')} !important;

    * {
      font-family: ${th('fontInterface')} !important;
    }
  }
  .annotator-item,
  .annotator-viewer div:first-of-type,
  .annotator-editor .annotator-item:first-child textarea {
    font-size: ${th('fontSizeBaseSmall')} !important;
    font-style: normal !important;
  }
`
const Annotator = BaseComponent =>
  class AnnotatorDiv extends React.Component {
    state = { app: null }
    componentDidMount() {
      this.startAnnotator()
    }
    setRef = elem => {
      this.elem = elem
    }
    startAnnotator = () => {
      const { toMark, user } = this.props
      const { app } = this.state
      const annOpts = {
        user_id: user,
        file_id: toMark,
      }
      if (app) {
        app.destroy().then(() => {
          this.start(this.elem, annOpts)
        })
      } else {
        this.start(this.elem, annOpts)
      }
    }
    start = (elm, options) => {
      const app = new annotator.App()
      app
        .include(annotator.ui.main, { element: elm })
        .include(annotator.storage.http, {
          prefix: '/annotations',
          urls: {
            create: '/',
            update: '/{id}',
            destroy: '/{id}',
            search: `/file/${options.file_id}`,
          },
        })
        .include(this.addHooks, options)
        .start()
        .then(() => {
          app.annotations.store.setHeader(
            'Authorization',
            `Bearer ${window.localStorage.getItem('token')}`,
          )
          app.annotations.load()
        })
      this.setState({ app })
    }
    addHooks = options => ({
      annotationsLoaded: annotations => {},
      beforeAnnotationCreated: annotation => {
        this.packAnnotation(annotation, options)
      },
      annotationCreated: annotation => {
        this.props.reload(true)
      },
      beforeAnnotationUpdated: annotation => {
        this.packAnnotation(annotation, options)
      },
      annotationUpdated: annotation => {
        this.props.reload(true)
      },
      beforeAnnotationDeleted: annotation => {
        this.packAnnotation(annotation, options)
      },
      annotationDeleted: annotation => {
        this.props.reload(true)
      },
    })

    packAnnotation = (annotation, options) => {
      annotation.user_id = options.user_id
      annotation.file_id = options.file_id
      annotation.ranges = JSON.stringify(annotation.ranges)
    }
    render() {
      const { toMark, user, children, style, ...props } = this.props
      return (
        <Annotate className="annotator" ref={this.setRef} style={style}>
          <AnnotatorStyles />
          <BaseComponent {...props}>{children}</BaseComponent>
        </Annotate>
      )
    }
  }

export default Annotator
