import React from 'react'
import styled from 'styled-components'
import { Link } from '@pubsweet/ui'
import { th } from '@pubsweet/ui-toolkit'
import { A, HTMLString } from './ui'

const ManuscriptHead = styled.div`
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: stretch;
  background-color: ${th('colorTextReverse')};
  border-bottom: ${th('borderWidth')} ${th('borderStyle')} ${th('colorBorder')};
  font-weight: 600;
  & > div {
    margin-bottom: 0;
    height: 100%;
    overflow: auto;
    & > div {
      padding: calc(${th('gridUnit')} * 2.5) calc(${th('gridUnit')} * 2);
    }
  }
  @media screen and (min-width: 871px) {
    & + .withHeader {
      height: calc(100% - (${th('gridUnit')} * 20.125));
    }
  }
`
const LeftSide = styled.div`
  flex: 1 1 1000px;
  & > div {
    max-width: 1000px;
    margin: 0 0 0 auto;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
  }
`
const RightSide = styled.div`
  flex: 1 1 500px;
  z-index: 1;
  & > div {
    max-width: 500px;
    margin: 0 auto 0 0;
    text-align: right;
  }
`

const SubmissionHeader = BaseComponent => ({
  currentUser,
  manuscript,
  children,
  ...props
}) => (
  <React.Fragment>
    <ManuscriptHead>
      <LeftSide>
        <div>
          {manuscript.id}: <HTMLString string={manuscript.meta.title} />
        </div>
      </LeftSide>
      <RightSide>
        <div>
          {currentUser.admin ? (
            <Link to={`/submission/${manuscript.id}/activity`}>Activity</Link>
          ) : (
            <A href="mailto:helpdesk@europepmc.org">Helpdesk</A>
          )}
        </div>
      </RightSide>
    </ManuscriptHead>
    <BaseComponent currentUser={currentUser} manuscript={manuscript} {...props}>
      {children}
    </BaseComponent>
  </React.Fragment>
)

export default SubmissionHeader
