import React, { Fragment } from 'react'
import { H2, Icon } from '@pubsweet/ui'
import styled from 'styled-components'
import moment from 'moment'

// import { th } from '@pubsweet/ui-toolkit'
// import styled from 'styled-components'
import { B, Table } from '../ui'
import { getStageStatus, STAGE, lastAudit } from './helper'

const ManuMeta = styled.div`
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  justify-content: space-between;
  margin: 10px 0;
`

const MetaColumn = styled.div`
  line-height: 75px;
`

const MetaList = styled.ul`
  list-style-type: none;
  padding-left: 2px;
  margin: 0 0;
`

const MetaItem = styled.li`
  line-height: 24px;
`

const ManuMetaSec = ({ manuscript }) => {
  const journal = manuscript.journal.journalTitle
  const auditInfo = manuscript.audits.reduce((info, audit) => {
    if (!info.timeInProcess) {
      info.timeInProcess = moment(audit.created).fromNow(true)
    }
    if (audit.objectType === 'team' && audit.changes) {
      if (audit.changes.role_name === 'submitter') {
        info.submitter = `${audit.user.givenNames} ${audit.user.surname}`
      } else if (audit.changes.role_name === 'reviewer') {
        info.reviewer = manuscript.teams.reduce((reviewer, team) => {
          if (reviewer) {
            return reviewer
          }

          if (team.role === 'reviewer') {
            if (
              team.teamMembers &&
              team.teamMembers.length > 0 &&
              team.teamMembers[0].alias &&
              team.teamMembers[0].alias.name
            ) {
              const { name } = team.teamMembers[0].alias
              reviewer = `${name.givenNames} ${name.surname}`
            }
          }
          return reviewer
        }, '')
      }
    }
    return info
  }, {})
  let claimedBy = ''
  if (manuscript.claimedBy) {
    claimedBy = `${manuscript.claimedBy.givenNames} ${
      manuscript.claimedBy.surname
    }`
  }
  return (
    <ManuMeta>
      <MetaColumn>
        <MetaList>
          <MetaItem>
            <B>Submitter:</B> {auditInfo.submitter || 'N/A'}
          </MetaItem>
          <MetaItem>
            <B>Reviewer:</B> {auditInfo.reviewer || 'N/A'}
          </MetaItem>
          <MetaItem>
            <B>Claimed by:</B> {claimedBy || 'N/A'}
          </MetaItem>
        </MetaList>
      </MetaColumn>
      <MetaColumn>
        <MetaList>
          <MetaItem>
            <B>Time in process:</B> {auditInfo.timeInProcess || 'N/A'}
          </MetaItem>
          <MetaItem>
            <B>Last activity:</B> {lastAudit(manuscript) || 'N/A'}
          </MetaItem>
          <MetaItem>
            <B>Journal:</B> {journal || 'N/A'}
          </MetaItem>
        </MetaList>
      </MetaColumn>
    </ManuMeta>
  )
}

const stageStatus = (manuStatus, stage) => {
  const whatStatus = getStageStatus(manuStatus, stage)
  if (whatStatus === STAGE.DONE) {
    return (
      <td>
        <Icon color="currentColor" size={3}>
          check
        </Icon>
      </td>
    )
  } else if (whatStatus === STAGE.IN_PROCESS) {
    return <td>In Process</td>
  }
  return <td>&nbsp;</td>
}

const StatusTable = styled(Table)`
  width: 100%;
`

const QuickView = props => (
  <Fragment>
    <H2>Quick view</H2>
    <hr />
    <ManuMetaSec {...props} />
    <StatusTable>
      <tbody>
        <tr>
          <th>Submitted:</th>
          <th>Initial author review</th>
          <th>Submission QA</th>
          <th>XML tagging</th>
          <th>XML QA</th>
          <th>Final author review</th>
          <th>Citation</th>
          <th>Published</th>
        </tr>
        <tr key="manuscript">
          {stageStatus(props.manuscript.status, 'submitted')}
          {stageStatus(props.manuscript.status, 'initialAuthorReview')}
          {stageStatus(props.manuscript.status, 'submissionQa')}
          {stageStatus(props.manuscript.status, 'xmlTagging')}
          {stageStatus(props.manuscript.status, 'xmlQa')}
          {stageStatus(props.manuscript.status, 'finalAuthorReview')}
          {stageStatus(props.manuscript.status, 'citation')}
          {stageStatus(props.manuscript.status, 'published')}
        </tr>
      </tbody>
    </StatusTable>
  </Fragment>
)

export default QuickView
