export const STAGE = Object.freeze({
  DONE: 1,
  IN_PROCESS: 2,
  NOT_STARTED: 3,
  UNDEFINED: 4,
})

const states = new Map()
states.set(['submission-error'], {
  submitted: STAGE.IN_PROCESS,
  initialAuthorReview: STAGE.NOT_STARTED,
  submissionQa: STAGE.NOT_STARTED,
  xmlTagging: STAGE.NOT_STARTED,
  xmlQa: STAGE.NOT_STARTED,
  finalAuthorReview: STAGE.NOT_STARTED,
  citation: STAGE.NOT_STARTED,
  published: STAGE.NOT_STARTED,
})
states.set(['in-review'], {
  submitted: STAGE.DONE,
  initialAuthorReview: STAGE.IN_PROCESS,
  submissionQa: STAGE.NOT_STARTED,
  xmlTagging: STAGE.NOT_STARTED,
  xmlQa: STAGE.NOT_STARTED,
  finalAuthorReview: STAGE.NOT_STARTED,
  citation: STAGE.NOT_STARTED,
  published: STAGE.NOT_STARTED,
})
states.set(['submitted'], {
  submitted: STAGE.DONE,
  initialAuthorReview: STAGE.DONE,
  submissionQa: STAGE.IN_PROCESS,
  xmlTagging: STAGE.NOT_STARTED,
  xmlQa: STAGE.NOT_STARTED,
  finalAuthorReview: STAGE.NOT_STARTED,
  citation: STAGE.NOT_STARTED,
  published: STAGE.NOT_STARTED,
})
states.set(['tagging'], {
  submitted: STAGE.DONE,
  initialAuthorReview: STAGE.DONE,
  submissionQa: STAGE.DONE,
  xmlTagging: STAGE.IN_PROCESS,
  xmlQa: STAGE.NOT_STARTED,
  finalAuthorReview: STAGE.NOT_STARTED,
  citation: STAGE.NOT_STARTED,
  published: STAGE.NOT_STARTED,
})
states.set(['xml-qa'], {
  submitted: STAGE.DONE,
  initialAuthorReview: STAGE.DONE,
  submissionQa: STAGE.DONE,
  xmlTagging: STAGE.DONE,
  xmlQa: STAGE.IN_PROCESS,
  finalAuthorReview: STAGE.NOT_STARTED,
  citation: STAGE.NOT_STARTED,
  published: STAGE.NOT_STARTED,
})
states.set(['xml-review'], {
  submitted: STAGE.DONE,
  initialAuthorReview: STAGE.DONE,
  submissionQa: STAGE.DONE,
  xmlTagging: STAGE.DONE,
  xmlQa: STAGE.DONE,
  finalAuthorReview: STAGE.IN_PROCESS,
  citation: STAGE.NOT_STARTED,
  published: STAGE.NOT_STARTED,
})
states.set(['xml-complete'], {
  submitted: STAGE.DONE,
  initialAuthorReview: STAGE.DONE,
  submissionQa: STAGE.DONE,
  xmlTagging: STAGE.DONE,
  xmlQa: STAGE.DONE,
  finalAuthorReview: STAGE.DONE,
  citation: STAGE.IN_PROCESS,
  published: STAGE.NOT_STARTED,
})
states.set(['ncbi-ready'], {
  submitted: STAGE.DONE,
  initialAuthorReview: STAGE.DONE,
  submissionQa: STAGE.DONE,
  xmlTagging: STAGE.DONE,
  xmlQa: STAGE.DONE,
  finalAuthorReview: STAGE.DONE,
  citation: STAGE.DONE,
  published: STAGE.IN_PROCESS,
})
states.set(['published'], {
  submitted: STAGE.DONE,
  initialAuthorReview: STAGE.DONE,
  submissionQa: STAGE.DONE,
  xmlTagging: STAGE.DONE,
  xmlQa: STAGE.DONE,
  finalAuthorReview: STAGE.DONE,
  citation: STAGE.DONE,
  published: STAGE.DONE,
})

export const getStageStatus = (manuStatus, stage) => {
  const state = Array.from(states.keys()).reduce((state, keys) => {
    if (state) {
      return state
    }
    if (keys.includes(manuStatus)) {
      return states.get(keys)
    }
    return state
  }, undefined)

  if (!state || !Object.prototype.hasOwnProperty.call(state, stage)) {
    return STAGE.UNDEFINED
  }
  return state[stage]
}
