import React from 'react'
import { withRouter } from 'react-router'
// import { Mutation } from 'react-apollo'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'
import { Button, H2, H3, H4, Icon } from '@pubsweet/ui'
import {
  A,
  Buttons,
  SectionContent as Content,
  SectionHeader as Header,
} from '../ui'
import { FileThumbnails } from '../preview-files'
// import { UPDATE_MANUSCRIPT } from '../operations'

const Help = styled.p`
  font-style: italic;
  display: flex;
  align-items: center;
`
const Annotations = styled.ul`
  font-size: ${th('fontSizeBaseSmall')};
  list-style-type: none;
  padding-left: 0;
  margin-left: 0;
  li {
    padding: ${th('gridUnit')};
    border: ${th('borderWidth')} ${th('borderStyle')} ${th('colorBorder')};
    border-top: 0;
    &:nth-child(odd) {
      background-color: ${th('colorBackgroundHue')};
    }
    &:first-child {
      border-top: ${th('borderWidth')} ${th('borderStyle')} ${th('colorBorder')};
    }
  }
`
const Option = styled.div`
  display: flex;
  flex-flow: row wrap;
  align-items: center;
  justify-content: space-between;
  min-height: calc(${th('gridUnit')} * 6);
  padding: ${th('gridUnit')} calc(${th('gridUnit')} * 3);
  & > * {
    margin: ${th('gridUnit')} auto;
  }
  @media screen and (max-width: 870px) {
    padding: ${th('gridUnit')} calc(${th('gridUnit')} * 4);
  }
`
const ListErrors = ({ annotations }) => (
  <div>
    {annotations.map(
      errorlist =>
        errorlist.value && (
          <div key={errorlist.name}>
            <H4>{errorlist.name} Preview Errors</H4>
            <Annotations>
              {errorlist.value.map(error => (
                <li key={error.id}>
                  <em>{error.quote}</em>
                  <br />
                  {error.text}
                </li>
              ))}
            </Annotations>
          </div>
        ),
    )}
  </div>
)

const ReviewForm = ({ manuscript, annotations, files }) => {
  if (manuscript.status === 'tagging') {
    return (
      <React.Fragment>
        <Option>
          <H2>Tagging complete?</H2>
          <Button primary>Send for XML QA</Button>
        </Option>
        <Content>
          <p>
            When all files have been uploaded and both the Web and PDF previews
            have been generated, please click the button above to move the
            manuscript to XML QA.
          </p>
        </Content>
      </React.Fragment>
    )
  } else if (manuscript.status === 'xml-qa') {
    return (
      <React.Fragment>
        <Header>
          <H2>QA manuscript web version</H2>
        </Header>
        <Content>
          <div>
            <p>
              {`Click the buttons `}
              <span className="hide-mobile">on the left</span>
              {` to preview both the PDF and Web versions generated from the manuscript. Click 'Submitted manuscript `}
              <span className="hide-mobile">side-by-side view</span>
              &apos;
              <span className="hide-mobile">, above,</span>
              {` to view the originally submitted manuscript file.`}
            </p>
          </div>
        </Content>
        {files && (
          <div>
            <Header>
              <H3>Other submitted files</H3>
            </Header>
            <Content>
              <FileThumbnails files={files} />
            </Content>
          </div>
        )}
        <Header>
          <H3>Review</H3>
        </Header>
        <Content>
          <div>
            <p>
              Approve Web and PDF previews, or mark any errors and request
              corrections.
            </p>
            <Help>
              <Icon size={2}>help-circle</Icon>
              <span>
                <A href="https://europepmc.org/Funders/" target="_blank">
                  How do I report errors?
                </A>
              </span>
            </Help>
            {annotations && <ListErrors annotations={annotations} />}
            <Buttons>
              <Button disabled={annotations} primary>
                Approve
              </Button>
              {annotations && <Button>Request corrections</Button>}
            </Buttons>
          </div>
        </Content>
      </React.Fragment>
    )
  } else if (manuscript.status === 'xml-triage') {
    return (
      <React.Fragment>
        <Header>
          <H2>Review correction request</H2>
        </Header>
        <Content>
          {annotations && <ListErrors annotations={annotations} />}
          <p>
            You can fix the errors and approve for final review, or send this
            list to the taggers to fix. If necessary, you may edit the error
            text from the preview panes.
          </p>
          <p>
            If an error is caused by missing or incomplete files, click
            &apos;Return for user upload&apos; and you will be given the
            opportunity to write a message explaining what is needed and send
            the manuscript back to the submitter or reviewer to upload files.
          </p>
          <Option>
            <H3>Errors fixed?</H3>
            <Button>Approve for final review</Button>
          </Option>
          <Option>
            <H3>Tagger error?</H3>
            <Button>Confirm for retagging</Button>
          </Option>
          <Option>
            <H3>Missing files?</H3>
            <Button>Return for user upload</Button>
          </Option>
        </Content>
      </React.Fragment>
    )
  } else if (manuscript.status === 'xml-review') {
    return (
      <React.Fragment>
        <Header>
          <H2>Review and approve</H2>
        </Header>
        <Content>
          <div>
            <p>
              Please review the Europe PMC-formatted web version of your
              manuscript. This is the final step in the manuscript submission
              process.
            </p>
            <p>
              Click the buttons <span className="hide-mobile">on the left</span>{' '}
              to preview both the PDF and Web versions generated from the
              manuscript. Click &apos;Submitted manuscript
              <span className="hide-mobile"> side-by-side view</span>
              &apos;
              <span className="hide-mobile">, above,</span> to view the
              originally submitted manuscript file.
            </p>
          </div>
        </Content>
        {files && (
          <div>
            <Header>
              <H3>Other submitted files</H3>
            </Header>
            <Content>
              <FileThumbnails files={files} />
            </Content>
          </div>
        )}
        <Header>
          <H3>Review</H3>
        </Header>
        <Content>
          <div>
            <p>
              Approve Web and PDF previews, or mark any errors and request
              corrections.
            </p>
            <Help>
              <Icon size={2}>help-circle</Icon>
              <span>
                <A href="https://europepmc.org/Funders/" target="_blank">
                  How do I report errors?
                </A>
              </span>
            </Help>
            {annotations && <ListErrors annotations={annotations} />}
            <Buttons>
              <Button disabled={annotations} primary>
                Approve
              </Button>
              {annotations && <Button>Request corrections</Button>}
            </Buttons>
          </div>
        </Content>
      </React.Fragment>
    )
  }
  this.props.history.push('/')
  return null
}

export default withRouter(ReviewForm)
