import React from 'react'
import { Button } from '@pubsweet/ui'
import { Loading, LoadingIcon } from '../ui'

const makeList = matchString => {
  const sups = matchString.match(
    /(supp(?!lemented|lementing|ort[\W]|ort(?!ing)|orting [^i]|ress|ly|li|ler)[\w.]*\s*[\w.]*|extended data)\s*(?!and)\w*(,?\s*(\d+|\w\d+))*((?!(\s*and\s*|-|\u2013|\u2014|&)supp|extended|fig|table)(\s*and\s*|-|\u2013|\u2014|&)\w*)?/gi,
  )
  const figs = matchString.match(
    /(\W(supp[\w.]*|extended data)\s*|\W?)fig[\w.]*\s*(\d+|\w\d+)\w*(,?\s*(\d+|\w\d+))*((\s*and\s*|-|\u2013|\u2014|&)(?!supp|extended|fig|table)(\d+|\w\d+|\w+)\w*)*/gi,
  )
  const tables = matchString.match(
    /\W((supp[\w.]*|extended data)\s*)?table[\w]*\s*(\d+|\w\d+)\w*(,?\s*(\d+|\w\d+))*((\s*and\s*|-|\u2013|\u2014|&)(?!supp|extended|fig|table)(\d+|\w\d+|\w+)\w*)*/gi,
  )
  const regexes = [
    {
      title: 'Supplements',
      array: [
        ...new Set(sups && sups.map(match => match.replace(/\s\s+/g, ' '))),
      ],
    },
    {
      title: 'Figures',
      array: [
        ...new Set(
          figs &&
            figs.map(match => match.replace(/^\W/, '').replace(/\s\s+/g, ' ')),
        ),
      ].filter(match => !/^(supp|extended data)/i.test(match)),
    },
    {
      title: 'Tables',
      array: [
        ...new Set(
          tables &&
            tables.map(match =>
              match.replace(/^\W/, '').replace(/\s\s+/g, ' '),
            ),
        ),
      ].filter(match => !/^(supp|extended data)/i.test(match)),
    },
  ]
  return regexes
}

class SubmitHighlights extends React.Component {
  state = { references: 'Supplements' }
  render() {
    const { highlights } = this.props
    const { references } = this.state
    const regexes = makeList(highlights)
    if (
      !regexes ||
      (regexes.length > 0 && !regexes.some(x => x.array.length > 0))
    ) {
      return <div>No results</div>
    }
    return (
      <div style={{ padding: 0 }}>
        <div style={{ display: 'flex', justifyContent: 'stretch' }}>
          {regexes.map(regex => {
            if (regex.array.length > 0) {
              return (
                <Button
                  key={regex.title}
                  onClick={() => this.setState({ references: regex.title })}
                  primary={references !== regex.title}
                  style={{ flex: 1, margin: '0 1px' }}
                >
                  {regex.title}
                </Button>
              )
            }
            return null
          })}
        </div>
        {regexes.length === 0 && (
          <Loading>
            <LoadingIcon />
          </Loading>
        )}
        {regexes.map(regex => {
          if (references === regex.title) {
            return (
              <ul key={regex.title}>
                {regex.array.sort().map(match => (
                  <li key={match}>{match}</li>
                ))}
              </ul>
            )
          }
          return null
        })}
      </div>
    )
  }
}

export default SubmitHighlights
