import React from 'react'
import * as mime from 'mime-types'
import { H1, H2 } from '@pubsweet/ui'
import { FileTypes } from '../../upload-files'
import { Table } from '../../ui'

export const AllowedFiles = () => {
  const mimetypes = FileTypes.reduce((types, type) => {
    const mimetype = type.substring(0, type.indexOf('/'))
    if (!types.some(t => t === mimetype)) {
      types.push(mimetype)
    }
    return types
  }, [])
  return (
    <div>
      <H1>Acceptable file types</H1>
      {mimetypes.map(type => (
        <div key={type}>
          <H2>{type.charAt(0).toUpperCase() + type.slice(1)}</H2>
          <Table>
            <tbody>
              <tr>
                <th>File extension</th>
                <th>MIME type</th>
              </tr>
              {FileTypes.filter(subtype => subtype.startsWith(type)).map(
                subtype => (
                  <tr key={subtype}>
                    <td>.{mime.extension(subtype)}</td>
                    <td>{subtype}</td>
                  </tr>
                ),
              )}
            </tbody>
          </Table>
        </div>
      ))}
    </div>
  )
}

export default AllowedFiles
