const passport = require('passport')
const AnnotationManager = require('../xpub-model/entities/annotation')
const authorization = require('pubsweet-server/src/helpers/authorization')

const authBearer = passport.authenticate('bearer', { session: false })

module.exports = app => {
  const ANNOTATIONS_URI = '/annotations'
  // GET single annotation
  app.get(`${ANNOTATIONS_URI}/:id`, authBearer, (req, res, next) => {
    authorization
      .can(req.user, 'read', { id: req.params.id, type: 'Annotation' })
      .then(result => {
        AnnotationManager.find(req.params.id)
          .then(annotation => {
            const rows = processRes([annotation])
            res.status(200).json(rows[0])
          })
          .catch(error => {
            next(error)
          })
      })
      .catch(error => {
        next(error)
      })
  })

  // GET file annotations
  app.get(`${ANNOTATIONS_URI}/review/:id`, authBearer, (req, res, next) => {
    authorization
      .can(req.user, 'read', { id: req.params.id, type: 'Review' })
      .then(result => {
        AnnotationManager.findByReviewId(req.params.id)
          .then(annotations => {
            const rows = processRes(annotations)
            res.status(200).json(rows)
          })
          .catch(error => {
            next(error)
          })
      })
      .catch(error => {
        next(error)
      })
  })

  // POST annotation
  app.post(`${ANNOTATIONS_URI}`, authBearer, (req, res, next) => {
    req.body = processReq(req.body)
    authorization
      .can(req.user, 'create', { id: null, type: 'Annotation', ...req.body })
      .then(result => {
        AnnotationManager.save(req.body)
          .then(annotation => {
            res.status(200).json(processQuery(annotation))
          })
          .catch(error => {
            next(error)
          })
      })
      .catch(error => {
        next(error)
      })
  })

  // PUT annotation
  app.put(`${ANNOTATIONS_URI}/:id`, authBearer, (req, res, next) => {
    req.body = processReq(req.body)
    authorization
      .can(req.user, 'update', { id: req.params.id, type: 'Annotation' })
      .then(result => {
        AnnotationManager.save(req.body)
          .then(annotation => {
            res.status(200).json(processQuery(annotation))
          })
          .catch(error => {
            next(error)
          })
      })
      .catch(error => {
        next(error)
      })
  })

  // DELETE annotation
  app.delete(`${ANNOTATIONS_URI}/:id`, authBearer, (req, res, next) => {
    authorization
      .can(req.user, 'delete', { id: req.params.id, type: 'Annotation' })
      .then(result => {
        AnnotationManager.delete(req.params.id)
          .then(() => {
            res.status(200).json({ message: 'deleted successfully' })
          })
          .catch(error => {
            next(error)
          })
      })
      .catch(error => {
        next(error)
      })
  })

  const processRes = rows => {
    rows = rows.map(row => ({
      id: row.id,
      quote: row.quote,
      ranges: row.ranges,
      text: row.comment,
    }))
    return rows
  }

  const processReq = row => {
    row.comment = row.text
    delete row.text
    return row
  }

  const processQuery = row => {
    row.text = row.comment
    delete row.comment
    return row
  }
}
