const logger = require('@pubsweet/logger')
const db = require('pubsweet-server/src/db')
const passport = require('passport')
const STATUS = require('http-status-codes')

const authBearer = passport.authenticate('bearer', { session: false })

const retrieveNewEmsId = async () => {
  const { rows } = await db.query(`SELECT nextval('manuscript_id_seq')`)

  if (rows && rows.length === 1 && rows[0].nextval) {
    return rows[0].nextval
  }

  return 0
}

module.exports = app => {
  // Create a collection
  app.post('/api/collections', authBearer, (req, res, next) => {
    logger.info('About to create a collection')

    const emsid = retrieveNewEmsId()
    emsid
      .then(id => {
        if (id) {
          req.body.emsid = id
          logger.info(`New emsid generated: ${id}`)
          next()
        } else {
          logger.error('emsid not available')
          res
            .status(STATUS.INTERNAL_SERVER_ERROR)
            .send({ error: 'emsid not available' })
        }
      })
      .catch(err => {
        logger.error('emsid not resolvable: ', err)
        res.status(STATUS.INTERNAL_SERVER_ERROR).send({ error: err })
      })
  })
}
