const config = require('config')
const Email = require('@pubsweet/component-send-email')
const {
  htmlEmailBase,
  setReviewerTemplate,
  newReviewerTemplate,
  checkReviewerTemplate,
  rejectSubmissionTemplate,
  removeDupeTemplate,
} = require('./templates')

const { sender, url, testAddress } = config['epmc-email']

const sendMail = (email, subject, messageInHtml, from = null) => {
  const mailData = {
    from: from || sender,
    to: testAddress || email,
    subject: `[Europe PMC plus] ${subject}`,
    html: htmlEmailBase(messageInHtml),
  }
  Email.send(mailData)
}

const userMessage = (email, subject, message, from = null) => {
  const regex = /\b((?:[a-z][\w-]+:(?:\/{1,3}|[a-z0-9%])|www\d{0,3}[.]|[a-z0-9.-]+[.][a-z]{2,4}\/)(?:[^\s()<>]+|\(([^\s()<>]+|(\([^\s()<>]+\)))*\))+(?:\(([^\s()<>]+|(\([^\s()<>]+\)))*\)|[^\s`!()[\]{};:'".,<>?«»“”‘’]))/i
  const linkAdded = message.replace(
    regex,
    '<a href="$&" style="color:#20699C">$&</a>',
  )
  const messageDiv = `<div style="white-space:pre-wrap">${linkAdded}</div>`
  sendMail(email, subject, messageDiv, from)
}

const reviewerEmail = ({ reviewer, manInfo, submitter, token }) => {
  const { title, givenNames, surname } = submitter
  const submitterName = `${title ? `${title} ` : ''}${givenNames} ${surname}`
  const { title: t, givenNames: g, surname: s } = reviewer.name
  const salutation = `${t ? `${t} ` : ''}${g} ${s}`
  let link = `${url}submission/${manInfo.id}/submit`
  let html = ''
  if (token === 'correction') {
    html = checkReviewerTemplate(salutation, manInfo.title, submitterName, link)
  } else if (reviewer.id) {
    html = setReviewerTemplate(salutation, manInfo.title, submitterName, link)
  } else {
    link = `${url}dashboard?claim=${token}`
    html = newReviewerTemplate(salutation, manInfo.title, submitterName, link)
  }
  const subject = `Approve submission of ${manInfo.id}`
  sendMail(reviewer.email, subject, html)
}

const submitterRejectEmail = ({ reviewer, manInfo, submitter, message }) => {
  const { title, givenNames, surname } = submitter
  const { email } = submitter.identities[0]
  const salutation = `${title ? `${title} ` : ''}${givenNames} ${surname}`
  const { title: t, givenNames: g, surname: s } = reviewer
  const reviewerName = `${t ? `${t} ` : ''}${g} ${s}`
  const link = `${url}submission/${manInfo.id}/submit`
  const html = rejectSubmissionTemplate(
    salutation,
    manInfo.title,
    reviewerName,
    message,
    link,
  )
  const subject = `${manInfo.id}: Submission rejected`
  sendMail(email, subject, html)
}

const removeDuplicateEmail = (user, badInfo, goodInfo) => {
  const { title, givenNames, surname } = user
  const { email } = user.identities[0]
  const salutation = `${title ? `${title} ` : ''}${givenNames} ${surname}`
  const pmcid =
    goodInfo['meta,articleIds'] &&
    goodInfo['meta,articleIds'].find(id => id.pubIdType === 'pmcid')
      ? goodInfo['meta,articleIds'].find(id => id.pubIdType === 'pmcid').id
      : null
  const html = removeDupeTemplate(
    salutation,
    badInfo.id,
    badInfo['meta,title'],
    goodInfo.id,
    pmcid,
  )
  const subject = `${badInfo.id}: Duplicate submission`
  sendMail(email, subject, html)
}

module.exports = {
  sendMail,
  userMessage,
  reviewerEmail,
  submitterRejectEmail,
  removeDuplicateEmail,
}
