const { Model } = require('objection')
const EpmcBaseModel = require('../epmc-base-model')

class Audit extends EpmcBaseModel {
  static get tableName() {
    return 'audit.audit_log'
  }

  static get schema() {
    return {
      properties: {
        id: { type: 'uuid' },
        created: { type: 'timestamp' },
        userId: { type: 'uuid' },
        action: { type: 'string' },
        objectId: { type: 'uuid' },
        originalData: { type: 'object' },
        changes: { type: 'object' },
        objectType: { type: 'string' },
        manuscriptId: { type: 'string' },
      },
    }
  }

  static get relationMappings() {
    const User = require('../user/data-access')
    return {
      user: {
        relation: Model.BelongsToOneRelation,
        modelClass: User,
        join: {
          from: 'audit.audit_log.user_id',
          to: 'users.id',
        },
      },
    }
  }

  static async getMetrics() {
    const metrics = Audit.query().select('*')
    return metrics
  }
}

module.exports = Audit
