/* eslint-disable no-prototype-builtins */
const Manuscript = require('../data-access')

// Transform from GraphQL data to Database model
const dManuscriptUpdate = (data, userId) => {
  const properties = {}
  if (data.meta && data.meta.title) {
    properties['meta,title'] = data.meta.title
  }
  if (data.meta && data.meta.articleIds) {
    properties['meta,articleIds'] = data.meta.articleIds
  }
  if (data.meta && data.meta.publicationDates) {
    properties['meta,publicationDates'] = data.meta.publicationDates
  }
  if (data.meta && data.meta.fundingGroup) {
    properties['meta,fundingGroup'] = data.meta.fundingGroup
  }
  if (data.meta && data.meta.hasOwnProperty('releaseDelay')) {
    properties['meta,releaseDelay'] = data.meta.releaseDelay
  }
  if (data.meta && data.meta.unmatchedJournal) {
    properties['meta,unmatchedJournal'] = data.meta.unmatchedJournal
  }
  if (data.status) {
    properties.status = data.status
  }
  if (data.hasOwnProperty('claimedBy')) {
    properties.claimedBy = data.claimedBy
  }
  if (data.journalId) {
    properties.journalId = data.journalId
  }
  if (userId) {
    properties.updatedBy = userId
  }
  return new Manuscript(properties)
}

const gJournal = model => {
  const journal = {
    id: model.id,
    journalTitle: model.journalTitle,
    meta: {
      publisherName: model['meta,publisherName'],
      issn: model['meta,issn'],
      nlmta: model['meta,nlmta'],
      nlmuniqueid: model['meta,nlmuniqueid'],
      pmcStatus: model['meta,pmcStatus'],
      pubmedStatus: model['meta,pubmedStatus'],
      firstYear: model['meta,firstYear'],
      endYear: model['meta,endYear'],
    },
  }
  return journal
}

// Transform from Database model to GraphQL data
const gManuscript = model => {
  const manuscript = {}
  manuscript.id = model.id
  manuscript.updated = model.updated
  manuscript.deleted = model.deleted
  manuscript.status = model.status
  manuscript.formState = model.formState
  if (model.journal) {
    manuscript.journal = gJournal(model.journal)
  }
  manuscript.meta = {}
  if (model['meta,title']) {
    manuscript.meta.title = model['meta,title']
  }
  if (model['meta,articleIds']) {
    manuscript.meta.articleIds = model['meta,articleIds']
  }
  if (model['meta,publicationDates']) {
    manuscript.meta.publicationDates = model['meta,publicationDates']
  }
  if (model.notes) {
    manuscript.meta.notes = model.notes
  }
  if (model['meta,fundingGroup']) {
    manuscript.meta.fundingGroup = model['meta,fundingGroup']
  }
  if (model['meta,releaseDelay']) {
    manuscript.meta.releaseDelay = model['meta,releaseDelay']
  }
  if (model['meta,unmatchedJournal']) {
    manuscript.meta.unmatchedJournal = model['meta,unmatchedJournal']
  }
  manuscript.files = model.files
  manuscript.claimedBy = model.claiming ? model.claiming : null
  if (model.teams) {
    manuscript.teams = model.teams.map(t => ({
      role: t.roleName,
      teamMembers: t.users.map(u => ({
        user: {
          id: u.id,
        },
        alias: {
          name: {
            title: u.title,
            surname: u.surname,
            givenNames: u.givenNames,
          },
        },
      })),
    }))
  }
  manuscript.audits = model.audits
  return manuscript
}

module.exports = {
  dManuscriptUpdate,
  gManuscript,
}
