const logger = require('@pubsweet/logger')
const Role = require('../entities/role/data-access')
const User = require('../entities/user/data-access')
const Team = require('../entities/team/data-access')
const Identity = require('../entities/identity/data-access')

exports.seed = async (knex, Promise) => {
  // Checking
  const role = await Role.selectByName('admin')
  if (role) {
    logger.info('Good. Already seeded.')
    return
  }

  // See organization
  await knex('organization').del()
  await knex('organization').insert([
    {
      name: 'Europe PMC Plus',
    },
  ])

  // Seed teams
  const adminRole = new Role({ name: 'admin', organization: true })
  await adminRole.save()

  const submitterRole = new Role({ name: 'submitter', organization: false })
  await submitterRole.save()

  const reviewerRole = new Role({ name: 'reviewer', organization: false })
  await reviewerRole.save()

  // Seed users
  const adminUser = new User({
    givenNames: 'Helpdesk',
    surname: 'EuropePMC',
    defaultIdentity: 'local',
    identities: [
      {
        email: 'helpdesk@europepmc.org',
        type: 'local',
        passwordHash: await Identity.hashPassword('password123'),
      },
    ],
  })

  const saved = await adminUser.save()

  // Seed the relationship
  const team = new Team({
    userId: saved.id,
    roleName: adminRole.name,
    updatedBy: saved.id,
  })
  await team.save()
}
